@@ -61,7 +61,7 @@ class DoExecuteTagPoliciesTask(
 
     @functools.lru_cache(maxsize=32)
     def target(self):
-        with self.hub_regional_client("organizations") as orgs:
+        with self.organizations_policy_client() as orgs:
             if self.account_id != "":
                 return self.account_id
             else:
@@ -72,16 +72,14 @@ class DoExecuteTagPoliciesTask(
 
     def has_policy_attached(self, orgs):
         paginator = orgs.get_paginator("list_policies_for_target")
-        for page in paginator.paginate(
-            TargetId=self.target(), Filter="TAG_POLICY"
-        ):
+        for page in paginator.paginate(TargetId=self.target(), Filter="TAG_POLICY"):
             for policy in page.get("Policies", []):
                 if policy.get("Name") == self.tag_policy_name:
                     return True
         return False
 
     def run(self):
-        with self.hub_regional_client("organizations") as orgs:
+        with self.organizations_policy_client() as orgs:
             self.info("Ensuring attachments for policies")
             policy_id = self.load_from_input("policy").get("Id")
             if self.has_policy_attached(orgs):
